@@ -3,7 +3,7 @@ package Bundle::DBD::PO;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '1.00';
 
 1;
 
@@ -17,6 +17,10 @@ $Id: PO.pm 53 2008-07-20 12:20:22Z steffenw $
 
 $HeadURL: https://dbd-po.svn.sourceforge.net/svnroot/dbd-po/trunk/DBD-PO/lib/DBD/PO.pm $
 
+=head1 VERSION
+
+1.00
+
 =head1 SYNOPSIS
 
     perl -MCPAN -e 'install Bundle::DBD::PO'
@@ -34,15 +38,39 @@ You could start running:
 
     perl -MCPAN -e 'install Bundle::CPAN'
 
+=head1 SUBROUTINES/METHODS
+
+none
+
+=head1 DIAGNOSTICS
+
+none
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+none
+
+=head1 DEPENDENCIES
+
+DBI
+
+L<DBD::PO>
+
+=head1 INCOMPATIBILITIES
+
+not known
+
+=head1 BUGS AND LIMITATIONS
+
+not known
+
 =head1 SEE ALSO
 
 L<Bundle::DBI>
 
 =head1 AUTHOR
 
-Steffen Winkler E<lt>F<STEFFENW at cpan.org>E<gt>
-
-=head1 THANKS
+Steffen Winkler
 
 This bundle was created by ripping of Bundle::libnet
 created by Graham Barr E<lt>F<gbarr.ti.com>E<gt>,
@@ -51,4 +79,15 @@ from Jochen Wiedemann E<lt>F<joe ar ipsoft.de>E<gt>.
 The template was then included in the DBI::DBD documentation
 by Jonathan Leffler E<lt>F<jleffler at informix.com>E<gt>.
 
-=cut
+=head1 LICENSE AND COPYRIGHT
+
+Copyright (c) 2008,
+Steffen Winkler
+E<lt>F<steffenw at cpan.org>E<gt>.
+All rights reserved.
+
+This module is free software;
+you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
+=cut
\ No newline at end of file
